@@ -148,12 +148,12 @@ gst_fftwspectrum_class_init (GstFFTWSpectrumClass * klass)
   gobject_class->get_property = gst_fftwspectrum_get_property;
 
   g_object_class_install_property (gobject_class, ARG_DEF_SIZE,
-      g_param_spec_int ("def_size", "Default Size", 
+      g_param_spec_int ("def-size", "Default Size", 
 	  "Apply a Fourier transform to this many samples at a time (default value)",
 	  1, G_MAXINT32, DEF_SIZE_DEFAULT, G_PARAM_READWRITE));
 
   g_object_class_install_property (gobject_class, ARG_DEF_STEP,
-      g_param_spec_int ("def_step", "Default Step", 
+      g_param_spec_int ("def-step", "Default Step", 
 	  "Advance the stream this many samples each time (default value)",
 	  1, G_MAXINT32, DEF_STEP_DEFAULT, G_PARAM_READWRITE));
 
